from leapp.libraries.common.config.version import is_rhel_realtime
from leapp.libraries.stdlib import api, CalledProcessError, run
from leapp.models import InstalledTargetKernelVersion, DefaultBootKernelInfo


def _get_kernel_version(kernel_name):
    try:
        kernels = run(['rpm', '-q', kernel_name], split=True)['stdout']
    except CalledProcessError:
        return ''

    for kernel in kernels:
        # name-version-release - we want the last two fields only
        version = '-'.join(kernel.split('-')[-2:])
        if 'el8' in version:
            return version
    return ''


def _is_kernel_uek():
    boot_kernel = next(api.consume(DefaultBootKernelInfo), None)
    if boot_kernel.kernel_type == 'kernel':
        return False
    else:
        return True


def process():
    if _is_kernel_uek():
        version = _get_kernel_version('kernel-uek')
        if version:
            api.produce(InstalledTargetKernelVersion(version=version))
            return
        else:
            api.current_logger().warning(
                'The kernel-uek rpm from OL 8 has not been detected. Switching to RHCK kernel.')

    # RHCK kernel
    version = _get_kernel_version('kernel')
    if version:
        api.produce(InstalledTargetKernelVersion(version=version))
    else:
        # This is very unexpected situation. At least one kernel has to be
        # installed always. Some actors consuming the InstalledTargetKernelVersion
        # will crash without the created message. I am keeping kind of original
        # behaviour in this case, but at least the let me log the error msg
        #
        api.current_logger().error('Cannot detect any kernel RPM')
        # StopActorExecutionError('Cannot detect any OL 8 kernel RPM.')
